==> v0.6.5.zip: bazarr/README.md <==
# bazarr
Bazarr is a companion application to Sonarr and Radarr. It can manage and download subtitles based on your requirements. You define your preferences by TV show or movie and Bazarr takes care of everything for you.

Be aware that Bazarr doesn't scan disk to detect series and movies: It only takes care of the series and movies that are indexed in Sonarr and Radarr.

# Status
[![GitHub issues](https://img.shields.io/github/issues/morpheus65535/bazarr.svg?style=flat-square)](https://github.com/morpheus65535/bazarr/issues)
[![GitHub stars](https://img.shields.io/github/stars/morpheus65535/bazarr.svg?style=flat-square)](https://github.com/morpheus65535/bazarr/stargazers)
[![Docker Pulls](https://img.shields.io/docker/pulls/linuxserver/bazarr.svg?style=flat-square)](https://hub.docker.com/r/linuxserver/bazarr/)
[![Discord](https://img.shields.io/badge/discord-chat-MH2e2eb.svg?style=flat-square)](https://discord.gg/MH2e2eb)

# Support
For installation and configuration instructions, see [wiki](https://github.com/morpheus65535/bazarr/wiki).

If you find a bug, please open an issue on [Github](https://github.com/morpheus65535/bazarr/issues).

You can also reach me on [Discord](https://discord.gg/MH2e2eb).

# Feature Requests
If you need something that is not already part of Bazarr, feel free to create a feature request on [Github](https://github.com/morpheus65535/bazarr/issues).

## Major Features Include:

* Support for major platforms: Windows, Linux, macOS, Raspberry Pi, etc.
* Automatically add new series and episodes from Sonarr
* Automatically add new movies and episodes from Radarr
* Series or movies based configuration for subtitles languages
* Scan your existing library for internal and external subtitles and download any missing
* Keep history of what was downloaded from where and when
* Manual search so you can download subtitles on demand
* Ability to delete external subtitles from disk
* Currently support 184 subtitles languages
* And a beautiful UI based on Sonarr

## Supported subtitles providers:
* addic7ed
* legendastv
* opensubtitles
* podnapisi
* shooter
* thesubdb
* tvsubtitles

## Screenshot

You can get more in the [screenshot](https://github.com/morpheus65535/bazarr/tree/master/screenshot) directory but it should look familiar:

![Series](/screenshot/series.png?raw=true "Series")

### License

* [GNU GPL v3](http://www.gnu.org/licenses/gpl.html)
* Copyright 2010-2017

==> v0.7.0.5.zip: bazarr/README.md <==
# bazarr
Bazarr is a companion application to Sonarr and Radarr. It manages and downloads subtitles based on your requirements. You define your preferences by TV show or movies and Bazarr takes care of everything for you.

Be aware that Bazarr doesn't scan disk to detect series and movies: It only takes care of the series and movies that are indexed in Sonarr and Radarr.

## Support on Beerpay
At the request of some, here is a way to demonstrate your appreciation for the efforts made in the development of Bazarr:
[![Beerpay](https://beerpay.io/morpheus65535/bazarr/badge.svg?style=beer-square)](https://beerpay.io/morpheus65535/bazarr)

You can also make a wish but keep in mind that we do not commit to make it happen:
[![Beerpay](https://beerpay.io/morpheus65535/bazarr/make-wish.svg?style=flat-square)](https://beerpay.io/morpheus65535/bazarr?focus=wish)

# Status
[![GitHub issues](https://img.shields.io/github/issues/morpheus65535/bazarr.svg?style=flat-square)](https://github.com/morpheus65535/bazarr/issues)
[![GitHub stars](https://img.shields.io/github/stars/morpheus65535/bazarr.svg?style=flat-square)](https://github.com/morpheus65535/bazarr/stargazers)
[![Docker Pulls](https://img.shields.io/docker/pulls/linuxserver/bazarr.svg?style=flat-square)](https://hub.docker.com/r/linuxserver/bazarr/)
[![Discord](https://img.shields.io/badge/discord-chat-MH2e2eb.svg?style=flat-square)](https://discord.gg/MH2e2eb)

# Support
For installation and configuration instructions, see [wiki](https://github.com/morpheus65535/bazarr/wiki).

If you find a bug, please open an issue on [Github](https://github.com/morpheus65535/bazarr/issues).

You can also reach me on [Discord](https://discord.gg/MH2e2eb).

# Feature Requests
If you need something that is not already part of Bazarr, feel free to create a feature request on [Github](https://github.com/morpheus65535/bazarr/issues).

## Major Features Include:

* Support for major platforms: Windows, Linux, macOS, Raspberry Pi, etc.
* Automatically add new series and episodes from Sonarr
* Automatically add new movies and episodes from Radarr
* Series or movies based configuration for subtitles languages
* Scan your existing library for internal and external subtitles and download any missing
* Keep history of what was downloaded from where and when
* Manual search so you can download subtitles on demand
* Ability to delete external subtitles from disk
* Currently support 184 subtitles languages
* And a beautiful UI based on Sonarr

## Supported subtitles providers:
* addic7ed
* legendastv
* opensubtitles
* podnapisi
* shooter
* thesubdb
* tvsubtitles

## Screenshot

You can get more in the [screenshot](https://github.com/morpheus65535/bazarr/tree/master/screenshot) directory but it should look familiar:

![Series](/screenshot/1-series/series-2-episodes.png?raw=true "Series")

### License

* [GNU GPL v3](http://www.gnu.org/licenses/gpl.html)
* Copyright 2010-2017
